@@ -2,7 +2,7 @@ import json
 import hmac
 import hashlib
 
-from Monei import Configuration, ApiClient, PaymentsApi, ApiException
+from Monei import Configuration, ApiClient, PaymentsApi, ApiException, SubscriptionsApi, ApplePayDomainApi, __version__
 
 
 class MoneiClient(object):
@@ -20,10 +20,15 @@ class MoneiClient(object):
 
         # Enter a context with an instance of the API client
         with ApiClient(self.config) as api_client:
-            api_client.user_agent = 'MONEI/PYTHON/0.1.8'
-            self.payments = PaymentsApi(api_client)
+            api_client.user_agent = "MONEI/Python/" + __version__
+            self.Payments = PaymentsApi(api_client)
+            self.Subscriptions = SubscriptionsApi(api_client)
+            self.ApplePayDomain = ApplePayDomainApi(api_client)
 
-    def verifySignature(self, body, signature):
+            # aliases
+            self.payments = self.Payments
+
+    def verify_signature(self, body, signature):
         """Verifies response signature
         :param body: string JSON content to be verified
         :param signature: string signature to verify against
@@ -33,16 +38,16 @@ class MoneiClient(object):
         parts = {}
         signature_parts = signature.split(',')
         for part in signature_parts:
-            subparts = part.split('=')
-            parts[subparts[0]] = subparts[1]
+            parts = part.split('=')
+            parts[parts[0]] = parts[1]
 
-        calculatedHmac = hmac.new(
+        calculated_hmac = hmac.new(
             bytes(self.api_key, 'utf-8'),
             msg=bytes('{}.{}'.format(parts['t'], body), 'utf-8'),
             digestmod=hashlib.sha256
         ).hexdigest()
 
-        if calculatedHmac != parts['v1']:
+        if calculated_hmac != parts['v1']:
             raise ApiException(
                 status=401,
                 reason='[401] Signature verification failed'
